@@ -171,6 +171,10 @@ class ChessPlayer:
         """Resign from the game"""
         self.__game.resign(self)
         
+    def claimDraw(self):
+        """Claim a draw"""
+        self.__game.claimDraw(self)
+
     def outOfTime(self):
         """Report this players timer has expired"""
         self.__game.outOfTime(self)
@@ -276,7 +280,7 @@ class ChessGame:
     __spectators = None
     
     # The board to move on
-    __board = None
+    board = None
     
     # SAN en/decoders
     __sanConverter = None
@@ -300,8 +304,8 @@ class ChessGame:
         """Game constructor"""
         self.__players = []
         self.__spectators = []
-        self.__board = ChessGameBoard(self)
-        self.__sanConverter = ChessGameSANConverter(self.__board)
+        self.board = ChessGameBoard(self)
+        self.__sanConverter = ChessGameSANConverter(self.board)
         self.__moves = []
         self.__queuedCalls = []
         
@@ -313,7 +317,7 @@ class ChessGame:
         Returns a dictionary of the alive pieces (board.ChessPiece) keyed by location.
         Raises an IndexError exception if moveNumber is invalid.
         """
-        return self.__board.getAlivePieces(moveNumber)
+        return self.board.getAlivePieces(moveNumber)
     
     def getDeadPieces(self, moveNumber = -1):
         """Get the dead pieces from the game.
@@ -323,7 +327,7 @@ class ChessGame:
         Returns a list of the pieces (board.ChessPiece) in the order they were killed.
         Raises an IndexError exception if moveNumber is invalid.
         """
-        return self.__board.getDeadPieces(moveNumber)
+        return self.board.getDeadPieces(moveNumber)
     
     def setTimers(self, whiteTimer, blackTimer):
         """
@@ -390,6 +394,11 @@ class ChessGame:
         """
         assert(self.__whitePlayer is not None and self.__blackPlayer is not None)
         
+        # Disabled for now
+        #import network
+        #self.x = network.GameReporter('Test Game', 12345)
+        #print 'Reporting'
+
         # Load starting moves
         self.__currentPlayer = self.__whitePlayer
         for move in moves:
@@ -411,7 +420,7 @@ class ChessGame:
     def getSquareOwner(self, coord):
         """TODO
         """
-        piece = self.__board.getPiece(coord)
+        piece = self.board.getPiece(coord)
         if piece is None:
             return None
         
@@ -443,7 +452,7 @@ class ChessGame:
         else:
             assert(False)
 
-        move = self.__board.testMove(colour, start, end, promotionType = promotionType)
+        move = self.board.testMove(colour, start, end, promotionType = promotionType)
 
         return move is not None
     
@@ -496,8 +505,8 @@ class ChessGame:
                 return
 
         # Only use promotion type if a pawn move to far file
-        victim = self.__board.getPiece(end)
-        piece = self.__board.getPiece(start)
+        victim = self.board.getPiece(end)
+        piece = self.board.getPiece(start)
         promotion = None
         if piece is not None and piece.getType() is chess.board.PAWN:
             if colour is chess.board.WHITE:
@@ -510,11 +519,7 @@ class ChessGame:
         # Re-encode for storing and reporting
         sanMove = self.__sanConverter.encodeSAN(start, end, promotionType)
         canMove = chess.lan.encode(colour, start, end, promotionType = promotion)
-        moveResult = self.__board.movePiece(colour, start, end, promotionType)
-
-        # If for some reason we couldn't make the SAN move the use the CAN move instead
-        if sanMove is None:
-            sanMove = canMove        
+        moveResult = self.board.movePiece(colour, start, end, promotionType)
 
         if moveResult is None:
             print 'Illegal move: ' + str(move)
@@ -596,24 +601,31 @@ class ChessGame:
         
         'player' is the player resigning.
         """
-        if player is not self.__currentPlayer:
-            print 'Player attempted to resign out of turn'
-            return
-
-        # See if the resignation can be done without requesting
         rule = RULE_RESIGN
+        if player is self.__whitePlayer:
+            self.endGame(RESULT_BLACK_WINS, rule)
+        else:
+            self.endGame(RESULT_WHITE_WINS, rule)
+            
+    def claimDraw(self, player):
+        """
+        """
+        # TODO: Penalise if make an incorrect attempt
         try:
             move = self.__moves[-1]
         except IndexError:
-            pass
+            return False
         else:
             if move.fiftyMoveRule:
                 rule = RULE_FIFTY_MOVES
             elif move.threeFoldRepetition:
                 rule = RULE_THREE_FOLD_REPETITION
+            else:
+                return False
 
         self.endGame(RESULT_DRAW, rule)
-        
+        return True
+
     def killPlayer(self, player):
         """Report a player has died
         
@@ -669,7 +681,7 @@ class ChessGame:
         for file in '12345678':
             for rank in 'abcdefgh':
                 coord = rank + file
-                piece = self.__board.getPiece(coord)
+                piece = self.board.getPiece(coord)
                 if piece is None:
                     continue
 
@@ -685,6 +697,21 @@ class ChessGame:
         for player in self.__players:
             player.onPieceMoved(piece, start, end, delete)
 
+class NetworkChessGame(ChessGame):
+    """
+    """
+    
+    def move(self, player, move):
+        """Get a player to make a move.
+        
+        'player' is the player making the move.
+        'move' is the move to make. It can be of the form:
+               A coordinate move in the form ((file0, rank0), (file1, rank1), promotionType) ((int, int), (int, int), chess.board.PIECE_TYPE) or
+               A SAN move (string).
+        """
+        # Send to the server
+        
+            
 if __name__ == '__main__':
     game = ChessGame()
     
