@@ -18,7 +18,7 @@ class Player:
 class Game:
     name = ''
     
-    path = ''
+    path = None
     
     duration = 0
     
@@ -29,6 +29,93 @@ class Game:
         self.black = Player()
         self.moves = []
     
+class NetworkFeedback:
+    """Template class for feedback from a network game selector"""
+    
+    def setProfile(self, profile):
+        pass
+    
+    def joinRoom(self, room):
+        pass
+    
+    def joinTable(self, table):
+        pass
+    
+class NetworkController:
+    """"""
+    
+    def setVisible(self, isVisible):
+        pass
+    
+    def addProfile(self, profile, name):
+        pass
+    
+    def setBusy(self, isBusy):
+        pass
+    
+    def addChat(self, user, channel, text):
+        """Add chat 
+        """
+        pass
+    
+    def addRoom(self, index, name, description, room, protocol):
+        """Add a game room.
+        
+        'index' ???
+        'name' is the name of the room (string).
+        'description' is a description of the room (string).
+        'room' is the room to add (user-defined)
+        'protocol' ???
+        """
+        pass
+
+    def removeRoom(self, room):
+        pass
+    
+    def clearRooms(self):
+        pass
+    
+    def addTable(self, name, table):
+        pass
+
+    def removeTable(self, table):
+        pass
+    
+    def clearTables(self):
+        pass
+    
+    def addPlayer(self, player, name, icon):
+        pass
+    
+    def removePlayer(self, player):
+        pass
+    
+    def clearPlayers(self):
+        pass
+
+    def addAdvert(self, title, rating, advert):
+        """Add a game advert.
+        
+        'title' is the title of the advert (string).
+        'rating' is the rating for this game (string).
+        'advert' is an object to key this advert with (user-defined).
+        """
+        pass
+        
+    def removeAdvert(self, advert):
+        """Remove a game advert.
+        
+        'advert' is an object that was passed into addAdvert().
+        """
+        pass
+    
+    def requestGame(self, gameName):
+        """Request this player joins a game.
+        
+        'gameName' is the name of the game this player requested to join (string).
+        """
+        pass
+    
 class ViewFeedback:
     """Template class for feedback from a view object"""
     
@@ -120,9 +207,13 @@ class ViewFeedback:
         'filename' is the file to save to (string or None to save to last filename).
         """
         pass
-
-    def close(self):
-        """This method is called when the user requests this view be closed"""
+    
+    def regsign(self):
+        """Indicates the human player wants to resign"""
+        pass
+    
+    def claimDraw(self):
+        """Indicates the human player wants to claim a draw"""
         pass
 
 class ViewController:
@@ -161,11 +252,7 @@ class ViewController:
         'requiresAttention' is a flag to show if this view requires attention.
         """
         pass
-    
-    def close(self):
-        """Close this view"""
-        pass
-    
+
 class UIFeedback:
     """Template class for feedback from a UI"""
     
@@ -213,6 +300,11 @@ class UIFeedback:
         print 'Loading game ' + path
         return None
 
+    def onNewNetworkGame(self):
+        """
+        """
+        pass
+
     def onQuit(self):
         """Called when the user quits the program"""
         pass
@@ -254,6 +346,29 @@ class Timer:
     def delete(self):
         """Delete this timer"""
         pass
+    
+class Log:
+    """
+    """
+        
+    def addBinary(self, data, style = None):
+        """
+        """
+        pass
+
+    def addText(self, text, style = None):
+        """
+        """
+        pass
+    
+    def addLine(self, text, style = None):
+        """
+        """
+        pass
+
+    def close(self):
+        """
+        """
 
 class UI:
     """Template class for a glChess UI.
@@ -266,6 +381,9 @@ class UI:
         """
         pass
     
+    def addLogWindow(self, title, executable, description):
+        pass
+    
     def startAnimation(self):
         """Start the animation callback"""
         pass
@@ -298,27 +416,25 @@ class UI:
         """
         return None
 
-    def setDefaultView(self, feedback):
-        """Set the default view to render.
+    def setView(self, title, feedback, isPlayable = True):
+        """Set the view to display.
         
+        'title' is the title for the view (string).
         'feedback' is a object to report view events with (extends ViewFeedback).
-        
-        This will override the previous default view.
+        'isPlayable' is True if this view can be played.
         
         Returns a view controller object (extends ViewController).
         """
         return None
     
-    def addView(self, title, feedback):
-        """Add a view to the UI.
+    def addNetworkDialog(self, feedback):
+        """
+        'feedback' is a object to report view events with (extends NetworkFeedback).
         
-        'title' is the title for the view (string).
-        'feedback' is a object to report view events with (extends ViewFeedback).
-        
-        Returns a view controller object (extends ViewController).
+        Returns a network controller object (excends NetworkController).
         """
         return None
-
+    
     def reportGameLoaded(self, game):
         """Report a loaded game as required by onGameLoad().
         
@@ -326,6 +442,21 @@ class UI:
         """
         pass
     
+    def addNetworkGame(self, name, game):
+        """Report a detected network game.
+        
+        'name' is the name of the network game (string).
+        'game' is the game detected (user-defined).
+        """
+        pass
+    
+    def removeNetworkGame(self, game):
+        """Report a network game as terminated.
+        
+        'game' is the game that has removed (as registered with addNetworkGame()).
+        """
+        pass
+        
     def close(self):
         """Report the application has ended"""
         pass
