@@ -46,7 +46,7 @@ NORMAL_LINE_WIDTH = 1 # The size of the line we draw around a box
 SPACING_FACTOR = 40 # The size of a box compared (roughly) to the size
                     # of padding -- the larger this is, the smaller
                     # the spaces
-SMALL_TO_BIG_FACTOR = 3 # The number of times wider than a small line a big line is.
+SMALL_TO_BIG_FACTOR = 3.5 # The number of times wider than a small line a big line is.
 
 class NumberSelector (gtk.EventBox):
 
@@ -258,6 +258,12 @@ class NumberBox (gtk.Widget):
             # Then add
             self.set_text_interactive(txt)
 
+    def note_changed_cb (self, w, top=False):
+        if top:
+            self.set_note_text_interactive(top_text=w.get_text())
+        else:
+            self.set_note_text_interactive(bottom_text=w.get_text())
+
     def show_note_editor (self, top=True):
         alloc = self.get_allocation()
         w = gtk.Window()
@@ -272,12 +278,9 @@ class NumberBox (gtk.Widget):
         if top: e.set_text(self.top_note_text)
         else: e.set_text(self.bottom_note_text)
         w.add(f)
-        if top:
-            e.connect('changed',lambda *args: self.set_note_text_interactive(top_text=e.get_text()))
-        else:
-            e.connect('changed',lambda *args: self.set_note_text_interactive(bottom_text=e.get_text()))
-        e.connect('focus-out-event',lambda *args: w.destroy())
-        e.connect('activate',lambda *args: w.destroy())
+        e.connect('changed', self.note_changed_cb, top)
+        e.connect('focus-out-event',lambda e, ev, w: w.destroy(), w)
+        e.connect('activate',lambda e, w: w.destroy(), w)
         x,y = self.window.get_origin()
         if top:
             w.move(x,y)
@@ -286,6 +289,11 @@ class NumberBox (gtk.Widget):
         w.show_all()
         e.grab_focus()
 
+    def number_changed_cb (self, ns, w):
+        w.destroy()
+        self.set_text_interactive('')
+        self.set_text_interactive(str(ns.get_value()))
+
     def show_number_picker (self):
         #self.number_picker_mode = True
         #return
@@ -300,13 +308,9 @@ class NumberBox (gtk.Widget):
         w.set_property('skip-taskbar-hint', True)
         w.set_decorated(False)
         ns = NumberSelector(upper=self.upper,default=self.get_value())
-        def number_changed_cb (b):
-            w.destroy()
-            self.set_text_interactive('')
-            self.set_text_interactive(str(b.get_value()))
-        ns.connect('changed',number_changed_cb)
+        ns.connect('changed', self.number_changed_cb, w)
         w.grab_focus()
-        w.connect('focus-out-event',lambda *args: w.destroy())
+        w.connect('focus-out-event',lambda w, ev: w.destroy())
         w.add(ns)
         w.show()
         r = w.get_allocation()
@@ -461,6 +465,7 @@ class NumberBox (gtk.Widget):
         self.draw_text(cr)
         if self.draw_boxes and self.is_focus():
             self.draw_note_area_highlight_box(cr)
+        
 
     def draw_background_color (self, cr):        
         if self.read_only:
